import board, displayio, rgbmatrix, framebufferio, time, busio, terminalio, pwmio, adafruit_vl53l1x, digitalio, adafruit_imageload
import adafruit_display_text.label as label
from adafruit_display_shapes.polygon import Polygon
from adafruit_motor import servo
from adafruit_debouncer import Button
from audiopwmio import PWMAudioOut as AudioOut

from adafruit_apds9960.apds9960 import APDS9960

audio = AudioOut(board.GP22)

from audiomp3 import MP3Decoder

# set path to the folder where the sound files can be found on the device, example below is for a folder named alarm
path = "sounds/"

# set up the mp3 decoder
filename = "breen_bang.mp3"
mp3_file = open(path + filename, "rb")
decoder = MP3Decoder(mp3_file)

# Call this function passing in a String for the full filename with extension.
def play_mp3(filename, side):
    decoder.file = open(path + filename, "rb")
    audio.play(decoder)
    while audio.playing:
        text = side + "\nSCORE!"
        text_area = label.Label(terminalio.FONT, text=text)
        text_area.x = 10
        text_area.y = 10
        display.show(text_area)
        servo_left.throttle = 0
        servo_right.throttle = 0

button_input1 = digitalio.DigitalInOut(board.GP14) # Wired to GP15
button_input1.switch_to_input(digitalio.Pull.UP) # Note: Pull.UP for external buttons
button1 = Button(button_input1) # NOTE: False for external buttons

button_input2 = digitalio.DigitalInOut(board.GP28) # Wired to GP15
button_input2.switch_to_input(digitalio.Pull.UP) # Note: Pull.UP for external buttons
button2 = Button(button_input2) # NOTE: False for external buttons

i2c = busio.I2C(board.GP17, board.GP16)
multi_sensor = APDS9960(i2c)
multi_sensor.enable_proximity = True

i2c = busio.I2C(board.GP27, board.GP26)
distance_sensor = adafruit_vl53l1x.VL53L1X(i2c)
distance_sensor.distance_mode = 1

pwm_left = pwmio.PWMOut(board.GP15, frequency=50)
servo_left = servo.ContinuousServo(pwm_left)

pwm_right = pwmio.PWMOut(board.GP21, frequency=50)
servo_right = servo.ContinuousServo(pwm_right)

displayio.release_displays()
matrix = rgbmatrix.RGBMatrix(
    width=64, bit_depth=2,
    rgb_pins=[board.GP0, board.GP1, board.GP2, board.GP3, board.GP4, board.GP5],
    addr_pins=[board.GP6, board.GP7, board.GP8, board.GP9],
    clock_pin=board.GP10, latch_pin=board.GP12, output_enable_pin=board.GP13)
display = framebufferio.FramebufferDisplay(matrix)

def bmp(filename):
    g = displayio.Group()
    b, p = adafruit_imageload.load(filename)
    t = displayio.TileGrid(b, pixel_shader = p)
    if b.width >= 64:
        t.x = 0
    else:
        t.x = round((64 - b.width) / 2)
    if b.height >= 32:
        t.y = 0
    else:
        t.y = round((32 - b.height) / 2)
    g.append(t)
    display.show(g)

#splash = displayio.Group()

# color_bitmap = displayio.Bitmap(320, 240, 1)
# color_palette = displayio.Palette(1)
# color_palette[0] = 0xFFFFFF
# bg_sprite = displayio.TileGrid(color_bitmap, x=0, y=0, pixel_shader=color_palette)
# splash.append(bg_sprite)

# splash.append(Line(220, 130, 270, 210, 0xFF0000))
# splash.append(Line(270, 210, 220, 210, 0xFF0000))
# splash.append(Line(220, 210, 270, 130, 0xFF0000))
# splash.append(Line(270, 130, 220, 130, 0xFF0000))

# triangle = Triangle(170, 50, 120, 140, 210, 160, fill=0x00FF00, outline=0xFF00FF)
# splash.append(triangle)

#display.show(splash)

distance_sensor.timing_budget = 50

distance_sensor.start_ranging()

text = "GET\nREADY!"
text_area = label.Label(terminalio.FONT, text=text)
text_area.x = 10
text_area.y = 10
display.show(text_area)
time.sleep(3)

bmp("red.bmp")
time.sleep(2)
bmp("background.bmp")

# text = "GO!!!"
# text_area = label.Label(terminalio.FONT, text=text)
# text_area.x = 15
# text_area.y = 15
# display.show(text_area)

but1 = False
but2 = False

while True:
    bmp("background.bmp")
    reading = multi_sensor.proximity
    if reading > 160 or reading < 110:
        print("LEFT SCORE")
        play_mp3("breen_bang.mp3", "LEFT")
    button1.update()
    if button1.pressed:
        servo_left.throttle = .08
    button2.update()
    if button2.pressed:
#         print("pressed")
        servo_right.throttle = -.1
    distance = distance_sensor.distance
    if distance == None:
        pass
    elif int(distance) < 15:
        print(distance)
        print("RIGHT SCORE")
        play_mp3("breen_bang.mp3", "RIGHT")
